import { __decorate } from "tslib";
import { observable } from '@microsoft/fast-element';
import { from } from 'rxjs';
import { extractFieldDefinitions, toFieldMetadata, } from '../../../metadata';
/**
 * @internal
 */
export class DatasourceMock {
    constructor() {
        this.fetchMetadataRequired = true;
        this.fetchingMetadata = false;
        this.originalFieldDef = [];
        this.fieldMetadata = [];
        this.requestFields = [];
        this.availableIndexes = [];
    }
    init(options, fetchMeta) {
        return Promise.resolve(this.initialized);
    }
    /**
     * Convenience method to avoid you having to prime connect etc.
     * @param meta - The metadata to set.
     */
    setMetadata(meta) {
        var _a;
        this.availableIndexes = (_a = meta.INDEXES) !== null && _a !== void 0 ? _a : [];
        this.originalFieldDef = extractFieldDefinitions(meta);
        this.fieldMetadata = toFieldMetadata(this.originalFieldDef);
        this.requestFields = meta.REQUEST_FIELD || [];
        this.fetchMetadataRequired = false;
    }
    unsetMedata() {
        this.availableIndexes = [];
        this.originalFieldDef = [];
        this.fieldMetadata = [];
        this.requestFields = [];
        this.fetchMetadataRequired = true;
    }
    /**
     * Convenience method to avoid you having to prime connect etc.
     * @param message - The Message to stream.
     */
    setStream(message) {
        this.stream = from(Promise.resolve(message));
    }
    unsetStream() {
        this.stream = undefined;
    }
    deinit() { }
    destroy() { }
    validResourceName(resourceName) {
        if (!resourceName)
            return false;
        if (!resourceName.trim().length)
            return false;
        return true;
    }
    getMetadata(resourceName) {
        return Promise.resolve(this.fieldMetadata);
    }
    snapshot(params) { }
    snapshotFiltered(rowId) { }
    updateData(data) {
        return Promise.resolve();
    }
    dataHandler(data) {
        return [];
    }
    addView(view) { }
    dropView(view) { }
    setFilter(name, value, type) {
        return Promise.resolve();
    }
    clearFilter(name) {
        return Promise.resolve();
    }
    createItem(data) {
        return Promise.resolve('');
    }
    deleteItem(itemId) {
        return Promise.resolve();
    }
    updateItem(itemId, data) {
        return Promise.resolve();
    }
}
__decorate([
    observable
], DatasourceMock.prototype, "status", void 0);
__decorate([
    observable
], DatasourceMock.prototype, "fetchMetadataRequired", void 0);
__decorate([
    observable
], DatasourceMock.prototype, "originalFieldDef", void 0);
__decorate([
    observable
], DatasourceMock.prototype, "fieldMetadata", void 0);
__decorate([
    observable
], DatasourceMock.prototype, "requestFields", void 0);
__decorate([
    observable
], DatasourceMock.prototype, "availableIndexes", void 0);
